pub(crate) struct MessageCacheKey {
pub(crate) transaction_id: Option<OwnedTransactionId>,
pub(crate) event_id: Option<OwnedEventId>,
pub(crate) is_edited: bool,
}Expand description
The data used as a cache key for messages.
This is used when there is no reliable way to detect if the content of a message changed. For example, the URI of a media file might change between a local echo and a remote echo, but we do not need to reload the media in this case, and we have no other way to know that both URIs point to the same file.
Fields
transaction_id: Option<OwnedTransactionId>The transaction ID of the event.
Local echo should keep its transaction ID after the message is sent, so we do not need to reload the message if it did not change.
event_id: Option<OwnedEventId>The global ID of the event.
Local echo that was sent and remote echo should have the same event ID, so we do not need to reload the message if it did not change.
is_edited: boolWhether the message is edited.
The message must be reloaded when it was edited.
Implementations
Sourceimpl MessageCacheKey
impl MessageCacheKey
Sourcepub(crate) fn should_reload(&self, new: &MessageCacheKey) -> bool
pub(crate) fn should_reload(&self, new: &MessageCacheKey) -> bool
Whether the given new MessageCacheKey should trigger a reload of the
message compared to this one.