pub(crate) struct PasswordValidity {
pub(crate) has_lowercase: bool,
pub(crate) has_uppercase: bool,
pub(crate) has_number: bool,
pub(crate) has_symbol: bool,
pub(crate) has_length: bool,
pub(crate) progress: u32,
}Expand description
The result of a password validation.
Fields
has_lowercase: boolWhether the password includes at least one lowercase letter.
has_uppercase: boolWhether the password includes at least one uppercase letter.
has_number: boolWhether the password includes at least one number.
has_symbol: boolWhether the password includes at least one symbol.
has_length: boolWhether the password is at least 8 characters long.
progress: u32The percentage of checks passed for the password, between 0 and 100.
If progress is 100, the password is valid.
Implementations